/* Copyright (C) 2005 Coopi <gnu@coopi.org>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
 
   You should have received a copy of the GNU General Public
   License along with this program; if not, write to the
   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
*/

using Gtk;
using GLib;
using Glade;
using System;
using System.IO;
using System.Text;
using System.Timers;
using System.Threading;
using System.Collections;
using System.Xml;
using System.Web;
using GNU.Gettext;
using SdlDotNet;
using ICSharpCode.SharpZipLib.Zip;

namespace ssm {

	public class functions {

		// calcola la durata della presentazione
		public static string show_time(ref Gtk.SpinButton spinSec, int n_foto) {
			try {
				int s = ((n_foto * Convert.ToInt32(spinSec.Value)) + 5) % 60;
				int m = (((n_foto * Convert.ToInt32(spinSec.Value)) + 5) - s) / 60;
				int mm = m % 60;
				int h = (m - (m % 60)) / 60;

				return (h.ToString("D2") + "." + mm.ToString("D2") + "." + s.ToString("D2"));
			} catch (Exception e) {
				Console.WriteLine(e);
				return "00.00.00";
			}
		}

		// crea un messaggio dalla finestra 'f' di tipo 'mt' con bottoni 'bt' avente messaggio 'm'
		// se 'cancel'  true inserisce anche il tasto 'Annulla'
		// ritorna la risposta
		public static ResponseType message_box(Window f, MessageType mt, ButtonsType bt, bool cancel, string m) {
			MessageDialog msg;
			
			if (!cancel) msg = new MessageDialog(f, DialogFlags.DestroyWithParent, mt, bt, m);
			else {
				// crea un messaggio con anche il tasto 'Annulla'
				msg = new MessageDialog(f, DialogFlags.DestroyWithParent, mt, ButtonsType.None, m);
				msg.AddButton(Gtk.Stock.Cancel, ResponseType.Cancel);
				msg.AddButton(Gtk.Stock.No, ResponseType.No);
				msg.AddButton(Gtk.Stock.Yes, ResponseType.Yes);
			}

			ResponseType risp = (ResponseType)msg.Run();
			msg.Destroy();

			return risp;
		}

		// ritorna un cursore invisibile
		public static Gdk.Cursor ghost_cursor() {
			Gdk.Color col = new Gdk.Color(0,0,0);
			Gdk.Pixmap map = Gdk.Pixmap.CreateBitmapFromData(null,"",1,1);
			Gdk.Cursor cur = new Gdk.Cursor(map,map,col,col,0,0);

			return cur;
		}

		// ridimensione l'immagine per l'anteprima
		public static void size_preview(ref Gdk.Pixbuf pix) {
			try {
				pix = pix.ScaleSimple(150,(pix.Height * 150) / pix.Width,Gdk.InterpType.Bilinear);
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// ridimensiona l'immagine per l'anteprima a destra
		public static void size_preview_large(ref Gdk.Pixbuf pix, int wo, int ho, bool force, bool prop, Gdk.InterpType it) {
			try {
				int h = 0, w = 0;
				int nw = wo-250; // larghezza finestra - 200 (dimensione galleria a sx) - 50 (margine)
				int nh = ho-150; // altezza finestra - 100 (margine)
			
				// ridimensiona solo se  pi grande oppure se  forzato
				if ((pix.Width > nw || pix.Height > nh) || (force)) {
					if (prop) {
						// prova a ridimensionare prima per larghezza
						h = (pix.Height * nw) / pix.Width;
				
						// ridimensiona per altezza
						if (h > nh) w = (pix.Width * nh) / pix.Height;
				
						if (w == 0) pix = pix.ScaleSimple(nw,h,it);
						else pix = pix.ScaleSimple(w,nh,it);
					} else {
						// non mantiene le proporzioni
						pix = pix.ScaleSimple(nw,nh,it);
					}
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// ruota l'immagine del file 'f' rappresentata da 'pix' di 'degree' gradi
		public static void rotate(string f, ref Gdk.Pixbuf pix, int degree) {
			try {
				Surface img = new Surface(f);
				img.Rotate(degree);
				img.SaveBmp(ssm.home_dir + "/img_tmp.bmp");
				img.Close();

				pix = new Gdk.Pixbuf(ssm.home_dir + "/img_tmp.bmp");
				File.Delete(ssm.home_dir + "/img_tmp.bmp");
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}
		
		// carica un vettore di foto nella lista delle anteprime
		public static void load_dir(string[] elenco, Gtk.ListStore store, string[] rot, ProgressBar barWork) {
			try {
				if (ssm.is_working) return;
				
				int n = ssm.n_foto;
				int current_step = 0;
				
				ssm.is_working = true;
				ssm.create_progress(barWork, (uint)elenco.Length);

				// scorre tutta la lista e prende in considerazione solo i file corretti
				for (int i = 0; i < elenco.Length; i++) {
					ssm.set_progress(barWork, ++current_step);
					
					if (!File.Exists(elenco[i])) continue;
				
					// controlla l'estensione
					string ext = elenco[i].Substring(elenco[i].Length-4);

					if (ext.ToLower() == ".jpg" || ext.ToLower() == ".png" || ext.ToLower() == ".gif" || ext.ToLower() == "jpeg") {
						Gdk.Pixbuf pix = new Gdk.Pixbuf(elenco[i]);

						// controlla se c' la rotation
						if (rot != null) {
							if (rot[i] == "l") rotate(elenco[i], ref pix, 90);
							else if (rot[i] == "r") rotate(elenco[i], ref pix, 270);
							else if (rot[i] == "d") rotate(elenco[i], ref pix, 180);
						}
						
						// ridimensiona l'immagine per l'anteprima
						size_preview(ref pix);
					
						if (rot == null) store.AppendValues(pix,elenco[i],"");
						else store.AppendValues(pix,elenco[i],rot[i]);

						n++;
						
						// tiene libera la GUI
						while (Gtk.Application.EventsPending()) Gtk.Application.RunIteration();
					}
				}

				ssm.n_foto = n;
				ssm.destroy_progress(barWork);
				ssm.is_working = false;
			} catch (Exception e) {
				Console.WriteLine(e);
				ssm.destroy_progress(barWork);
				ssm.is_working = false;
			}
		}

		// crea una finestra di scelta dal padre 'f', con titolo 't', filtro/i 'ext', nome del filtro 'f_name'
		// con azione 'a'. se 'mult'  true consente la scelta multipla
		// ritorna un vettore di file/directory scelti o vuoto
		public static string[] file_chooser(Window f, string t, string ext, string f_name, FileChooserAction a, bool mult) {
			try {
				FileChooserDialog chooser = new FileChooserDialog(t,f,a);
				chooser.AddButton(Stock.Cancel, ResponseType.Cancel);

				// controlla se si tratta di apertura o salvataggio file
				if (a == FileChooserAction.Save) chooser.AddButton(Stock.Save, ResponseType.Ok);
				else if (a == FileChooserAction.Open || a == FileChooserAction.SelectFolder) {
					chooser.AddButton(Stock.Open, ResponseType.Ok);
					chooser.SelectMultiple = mult;
				}

				chooser.SetCurrentFolder(ssm.home_dir + "../");

				// se  stato passato un filtro allora lo imposta se l'azione  apertura di file(s)
				if (ext != "" && a == FileChooserAction.Open) {
					string[] filtri = ext.Split(';');
					Gtk.FileFilter filter = new Gtk.FileFilter();
					for (int i = 0; i < filtri.Length; i++) filter.AddPattern("*." + filtri[i]);
					filter.Name = f_name;

					chooser.AddFilter(filter);
				}

				string[] files = new string[1];
				string file = "";
				
				ResponseType risp = (ResponseType)chooser.Run();
				if (!mult) file = chooser.Filename;
				else files = chooser.Filenames;
				chooser.Destroy();
				
				// se si tratta di salvataggio controlla l'estensione perch non  stato applicato nessun filtro
				if (a == FileChooserAction.Save && ext != "" && file != null && file.Trim() != "") {
					if (!file.EndsWith("." + ext)) file += "." + ext;
				}
				
				if (risp == ResponseType.Ok) {
					if (!mult) files[0] = file;
						
					return files;
				}

				return new string[1];
			} catch (Exception e) {
				Console.WriteLine(e);
				return new string[1];
			}
		}

		// setta l'icona 's' alla finestra 'f'
		public static void set_window_icon(Window f, string s) {
			try {
				Gdk.Pixbuf icon = new Gdk.Pixbuf(s);
				f.Icon = icon;
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}
	}

	// classe principale
	public class ssm {
		
		[Widget] Window Form1;
		[Widget] Button cmdAdd, cmdAddDir, cmdElimina, cmdPulisci, cmdSfoglia, cmdOrario, cmdAntiorario, cmdCapovolgi, cmdCrea;
		[Widget] MenuItem mnuFile, mnuImpostazioni, mnuAiuto, mnuNew, mnuPrimo, mnuSecondo, mnuTerzo, mnuQuarto, mnuQuinto;
		[Widget] ImageMenuItem mnuEsci, mnuPreferenze, mnuSalva, mnuSalvaNome, mnuApriP, mnuApriG, mnuChiudiP, mnuCrea, mnuChiudiG, mnuPulisci, mnuAvvia, mnuInformazioni, mnuManual, mnuRecenti, mnuPromote;
		[Widget] Notebook scheda;
		[Widget] SpinButton spinSec;
		[Widget] Entry txtNome, txtSuono;
		[Widget] TreeView lista;
		[Widget] Gtk.Image imgFoto, imgLeft, imgRight, imgInverse;
		[Widget] Statusbar statusBar;
		[Widget] RadioButton optJpg, optPng, optBilinear, optHyper;
		[Widget] CheckButton chkForce, chkProporzioni;
		[Widget] ProgressBar barWork;
		[Widget] ComboBox cboSize, cboCompression;
		[Widget] Label lblAdd, lblAddDir, lblElimina, lblPulisci, lblCrea, lblSchedaUno, lblSchedaDue, lblNome, lblSuono, lblSecondi, lblSize, lblCompression, lblFormat, lblInterpolation, lblSfoglia;

		ListStore store;
		
		public static bool unix_sys = false, conf_elimina = false, conf_pulisci = false, apri_big = false, apri_galleria = false, close_window = true, propor = true, is_working = false;
		public static string nome_gallery = "", path = "", suono = "", nome_progetto = "", c_dir, seconds = "", file_to_open = "", p_language, home_dir;
		public static string[] images_list, recent_list;
		public static int spin_sec = 0, n_foto = 0, filtro = 0;

		int h_foto = 0, w_foto = 0;
		
		// timer che gestisce il resize della finestra
		System.Threading.Timer tmr_resize;
		
		// callback per il resize
		TimerCallback tmr_resize_del;
      
		// thread safe per il resize
		ThreadNotify notify_resize;

		// tabella dei target e dei tipi per il dnd
		enum TargetType {
				String,
				Url
		};

		private static TargetEntry[] target_table = new TargetEntry[] {
			new TargetEntry("STRING", 0, (uint)TargetType.String), // per linux
			new TargetEntry("text/uri-list", 0, (uint)TargetType.Url) // per windows
		};

		public static GettextResourceManager Catalog = new GettextResourceManager("i18n");
		public static void Main(string[] argv) {
			try {
				if (argv.Length > 0) file_to_open = argv[0];
			} catch (Exception e) {
				Console.WriteLine(e);
			}
			
			new ssm();
		}
		
		// costruttore
		public ssm() {
			try {
				Gtk.Application.Init();
			
				Glade.XML glade = new Glade.XML(null, "ssm.glade","Form1","SuperSlideMe");
				glade.Autoconnect(this);

				store = new ListStore(typeof(Gdk.Pixbuf),typeof(string),typeof(string));
				recent_list = new string[5];
			
				// controlla il sistema operativo
				unix_sys = !(Environment.OSVersion.Platform == PlatformID.Win32S || Environment.OSVersion.Platform == PlatformID.Win32Windows || Environment.OSVersion.Platform == PlatformID.Win32NT);

				// ricava il path dell'eseguibile e della home dell'utente
				c_dir = System.IO.Path.GetDirectoryName(System.Reflection.Assembly.GetExecutingAssembly().GetModules()[0].FullyQualifiedName) + "/";
				if (!unix_sys) home_dir = Environment.GetEnvironmentVariable("USERPROFILE") + "\\ssm";
				else home_dir = Environment.GetEnvironmentVariable("HOME") + "/.ssm";

				// assegna alla finestra la tabella dei target per il drop
				Gtk.Drag.DestSet(Form1, DestDefaults.All, target_table, Gdk.DragAction.Copy);

				// segnali
				Form1.DeleteEvent += Form1_delete;
				Form1.SizeAllocated += Form1_resize;
				Form1.DragDataReceived += Form1_receive;
				mnuNew.Activated += mnuNew_clicked;
				mnuEsci.Activated += mnuEsci_clicked;
				mnuPreferenze.Activated += mnuPreferenze_clicked;
				mnuApriP.Activated += mnuApriP_clicked;
				mnuApriG.Activated += mnuApriG_clicked;
				mnuCrea.Activated += mnuCrea_clicked;
				mnuSalva.Activated += mnuSalva_clicked;
				mnuSalvaNome.Activated += mnuSalvaNome_clicked;
				mnuChiudiP.Activated += mnuChiudiP_clicked;
				mnuChiudiG.Activated += mnuChiudiG_clicked;
				mnuPrimo.Activated += mnuPrimo_clicked;
				mnuSecondo.Activated += mnuSecondo_clicked;
				mnuTerzo.Activated += mnuTerzo_clicked;
				mnuQuarto.Activated += mnuQuarto_clicked;
				mnuQuinto.Activated += mnuQuinto_clicked;
				mnuPulisci.Activated += mnuPulisci_clicked;
				mnuAvvia.Activated += mnuAvvia_clicked;
				mnuInformazioni.Activated += mnuInformazioni_clicked;
				mnuManual.Activated += mnuManual_clicked;
				mnuPromote.Activated += mnuPromote_clicked;
				cmdAdd.Clicked += cmdAdd_clicked;
				cmdAddDir.Clicked += cmdAddDir_clicked;
				cmdElimina.Clicked += cmdElimina_clicked;
				cmdPulisci.Clicked += cmdPulisci_clicked;
				cmdSfoglia.Clicked += cmdSfoglia_clicked;
				cmdCrea.Clicked += cmdCrea_clicked;
				cmdOrario.Clicked += cmdOrario_clicked;
				cmdAntiorario.Clicked += cmdAntiorario_clicked;
				cmdCapovolgi.Clicked += cmdCapovolgi_clicked;
				txtNome.Changed += txtNome_changed;
				spinSec.ValueChanged += spinSec_change;
				lista.Selection.Changed += lista_changed;
				lista.RowActivated += lista_doubleclick;
				
				// imposta la funzione che si occupa del resizing
				notify_resize = new ThreadNotify(new ReadyEvent(do_resize));

				// crea il callback per il resize
				tmr_resize_del = new TimerCallback(tmr_resize_elapsed);

				// icona
				functions.set_window_icon(Form1, c_dir + "pixmaps/icon.png");
				
				lista.Model = store;
				lista.AppendColumn("",new CellRendererPixbuf(),"pixbuf",0);
				lista.AppendColumn("",new CellRendererText(),"text",1).Visible = false;
				lista.AppendColumn("",new CellRendererText(),"text",2).Visible = false;

				// sistema le icone dei tasti
				imgLeft.FromFile = c_dir + "pixmaps/rotate_left.png";
				imgRight.FromFile = c_dir + "pixmaps/rotate_right.png";
				imgInverse.FromFile = c_dir + "pixmaps/rotate_down.png";

				// trascrive il contenuto di tutta la GUI per l'internazionalizzazione
				lblAdd.Text = Catalog.GetString("Add photo");
				lblAddDir.Text = Catalog.GetString("Add folders");
				lblElimina.Text = Catalog.GetString("Delete photo");
				lblPulisci.Text = Catalog.GetString("Clear gallery");
				lblCrea.Text = Catalog.GetString("Create gallery");
				lblSchedaUno.Text = Catalog.GetString("Photogallery");
				lblSchedaDue.Text = Catalog.GetString("Options");
				lblNome.Markup = Catalog.GetString("<b>Gallery name</b>");
				lblSuono.Markup = Catalog.GetString("<b>Sound</b>");
				lblSecondi.Markup = Catalog.GetString("<b>Seconds</b>");
				lblSize.Markup = Catalog.GetString("<b>Images size</b>");
				lblCompression.Markup = Catalog.GetString("<b>Compression level</b>");
				lblFormat.Markup = Catalog.GetString("<b>Images format</b>");
				lblInterpolation.Markup = Catalog.GetString("<b>Interpolation</b>");
				lblSfoglia.Text = Catalog.GetString("Browse...");
				chkForce.Label = Catalog.GetString("Force resizing of small images");
				chkProporzioni.Label = Catalog.GetString("Keep ratio during resizing");
				cboSize.AppendText("640x480"); cboSize.AppendText("800x600"); cboSize.AppendText("1024x768");
				cboSize.AppendText(Catalog.GetString("Original"));
				cboCompression.AppendText(Catalog.GetString("High")); cboCompression.AppendText(Catalog.GetString("Medium")); 
				cboCompression.AppendText(Catalog.GetString("Low")); cboCompression.AppendText(Catalog.GetString("No compression"));
				((Gtk.Label)mnuFile.Child).LabelProp = Catalog.GetString("_File");
				((Gtk.Label)mnuImpostazioni.Child).LabelProp = Catalog.GetString("_Settings");
				((Gtk.Label)mnuAiuto.Child).LabelProp = Catalog.GetString("_Help");
				((Gtk.Label)mnuNew.Child).Text = Catalog.GetString("New project");
				((Gtk.Label)mnuApriP.Child).Text = Catalog.GetString("Open project");
				((Gtk.Label)mnuSalva.Child).Text = Catalog.GetString("Save project");
				((Gtk.Label)mnuSalvaNome.Child).Text = Catalog.GetString("Save project as");
				((Gtk.Label)mnuChiudiP.Child).Text = Catalog.GetString("Close project");
				((Gtk.Label)mnuCrea.Child).Text = Catalog.GetString("Create gallery");
				((Gtk.Label)mnuApriG.Child).Text = Catalog.GetString("Open gallery");
				((Gtk.Label)mnuAvvia.Child).Text = Catalog.GetString("Play slideshow");
				((Gtk.Label)mnuChiudiG.Child).Text = Catalog.GetString("Close gallery");
				((Gtk.Label)mnuRecenti.Child).Text = Catalog.GetString("Open recents");
				((Gtk.Label)mnuPulisci.Child).Text = Catalog.GetString("Clear recents");
				((Gtk.Label)mnuManual.Child).Text = Catalog.GetString("Manual");
				((Gtk.Label)mnuPromote.Child).Text = Catalog.GetString("Promote");
				barWork.Text = Catalog.GetString("Nothing to do");
				
				mnuCrea.Sensitive = false;
				mnuSalva.Sensitive = false;
				mnuSalvaNome.Sensitive = false;
				mnuChiudiP.Sensitive = false;
				mnuChiudiG.Sensitive = false;
				mnuAvvia.Sensitive = false;
				cboSize.Active = 2;
				cboCompression.Active = 3;
				chkForce.Active = false;
				chkProporzioni.Active = true;
			
				// carica le opzioni
				if (!load_options()) {
					conf_elimina = true;
					conf_pulisci = true;
					apri_big = false;
					apri_galleria = false;
					p_language = "English";
				}

				Form1.ShowAll();
				if (apri_big) Form1.Maximize();
				
				// crea i documenti recenti
				mnuPrimo.Visible = false;
				mnuSecondo.Visible = false;
				mnuTerzo.Visible = false;
				mnuQuarto.Visible = false;
				mnuQuinto.Visible = false;
				for (int i = 0; i < 5; i++) recent_list[i] = "";
				load_recent();

				// carica nelle variabili la grandezza della finestra
				Form1.GetSize(out w_foto, out h_foto);
				
				// controlla se  stato passato un file al programma
				if (file_to_open != "") open_recent(file_to_open);

				Gtk.Application.Run();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// riceve l'azione di drop di un file
		private void Form1_receive(object o, DragDataReceivedArgs args) {
			try {
				ArrayList lista_immagini = new ArrayList();
				
				// ricava tutti gli elementi (usa Data anzich Text per compatibilit con Windows)
				string[] files = System.Text.Encoding.GetEncoding(0).GetString(args.SelectionData.Data).Trim().Split('\n');
					
				// carica se possibile gli elementi
				for (int i = 0; i < files.Length; i++) {
					files[i] = files[i].Trim();
					
					// decodifica la stringa
					files[i] = HttpUtility.UrlDecode(files[i]);
					
					if (unix_sys) files[i] = files[i].Substring(7);
               else files[i] = files[i].Substring(8);
						
					if (files[i].ToLower().EndsWith(".jpg") || files[i].ToLower().EndsWith(".png") || files[i].ToLower().EndsWith(".gif") || files[i].ToLower().EndsWith(".jpeg")) {
						// carica un'immagine solo se c' un progetto aperto
						if (!mnuNew.Sensitive) lista_immagini.Add(files[i]);
					} else if (files[i].ToLower().EndsWith(".mp3") || files[i].ToLower().EndsWith(".ogg") || files[i].ToLower().EndsWith(".wav")) {
						// carica un suono solo se  stato droppato un file unico e se c' un progetto aperto
						if ((unix_sys && files.Length == 1) || (!unix_sys && files.Length == 2) && !mnuNew.Sensitive) txtSuono.Text = files[i];
					} else if (files[i].ToLower().EndsWith(".ssp") || files[i].ToLower().EndsWith(".ssg")) {
						// se  stato droppato un solo file allora pu caricare il progetto o la galleria
						if ((unix_sys && files.Length == 1) || (!unix_sys && files.Length == 2)) open_recent(files[i]);
					} else if (Directory.Exists(files[i])) {
						// carica il contenuto di una cartella solo se c' un progetto aperto
						if (!mnuNew.Sensitive) {
							string[] f = Directory.GetFiles(files[i]);
							foreach (string fs in f) lista_immagini.Add(fs);
						}
					}
				}

				// se ci sono immagini le carica (il suono, il progetto o la galleria sono stati gestiti prima)
				if (lista_immagini.Count > 0) {
					string[] imm = new string[lista_immagini.Count];					
					for (int i = 0; i < imm.Length; i++) imm[i] = lista_immagini[i].ToString();
					
					functions.load_dir(imm, store, null, barWork);
				}
				
				Gtk.Drag.Finish(args.Context, true, false, args.Time);
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// chiusura della finestra
		private void Form1_delete(object o, DeleteEventArgs args) {
			try {
				if (is_working) {
					args.RetVal = true;
					return;
				}
				
				// chiude il progetto o la galleria
				if (mnuChiudiP.Sensitive) {
					mnuChiudiP.Activate();
					
					// controlla che non sia stato risposto cancel
					if (!close_window) {
						// deve annullare l'evento destroy della finestra
						args.RetVal = true;
						return;
					}
				}
				if (mnuChiudiG.Sensitive) mnuChiudiG.Activate();
			
				// salva le opzioni
				save_options();
			
				// salva i file recenti
				save_recent();
			
				Gtk.Application.Quit();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// crea la progress con 'steps' steps
		public static void create_progress(ProgressBar barWork, uint steps) {
			if (steps > 1) barWork.DiscreteBlocks = steps;
			barWork.Text = "0 %";
			barWork.Fraction = 0;
		}

		// distrugge la progress bar
		public static void destroy_progress(ProgressBar barWork) {
			barWork.Text = Catalog.GetString("Nothing to do");
			barWork.Fraction = 0;
		}

		// avanza la progress bar allo step 'step' se possibile
		public static void set_progress(ProgressBar barWork, int step) {
			try {
				if (step <= barWork.DiscreteBlocks && step >= 0 && barWork.DiscreteBlocks > 1) {
					barWork.Fraction = (double) step / barWork.DiscreteBlocks;
					barWork.Text = Convert.ToString((int)(barWork.Fraction * 100)) + " %";
				}
			} catch (Exception e) {
				Console.WriteLine(e);
				destroy_progress(barWork);
			}
		}

		// crea un file in formato XML
		// prende come parametri il documento 'doc', il padre 'father' dell'elemento che deve essere aggiunto
		// il nome dell'opzione 'opt' e il suo valore 'val'
		private void save_xml(XmlDocument doc, XmlElement father, string opt, string val) {
			try {
				XmlElement elemento = doc.CreateElement("option");
				elemento.SetAttribute("name", opt);
				
				XmlText valore = doc.CreateTextNode(val);
				elemento.AppendChild(valore);
				
				father.AppendChild(elemento);
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// apre la finestra delle informazioni
		private void mnuInformazioni_clicked(object o, EventArgs args) {
			new informazioni();
		}

		// apre il manuale d'uso di super slide me
		private void mnuManual_clicked(object o, EventArgs args) {
			try {
				if (!unix_sys) System.Diagnostics.Process.Start(c_dir + "/doc/manual.html");
				else System.Diagnostics.Process.Start("sensible-browser", c_dir + "/doc/manual.html");
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// apre la pagina del sito di super slide me
		private void mnuPromote_clicked(object o, EventArgs args) {
			try {
				if (!unix_sys) System.Diagnostics.Process.Start(c_dir + "/doc/promote.html");
				else System.Diagnostics.Process.Start("sensible-browser", c_dir + "/doc/promote.html");
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// ridimensionamento della finestra
		private void Form1_resize(object o, EventArgs args) {
			try {
				int h, w;
				Form1.GetSize(out w, out h);
			
				if (imgFoto.Pixbuf != null && h_foto != 0 && w_foto != 0 && (h != h_foto || w != w_foto)) {
					// stoppa il timer se necessario e lo fa ripartire
					if (tmr_resize != null) tmr_resize.Dispose();
					tmr_resize = new System.Threading.Timer(tmr_resize_del, null, 500, 5000);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// evento del 'timer_resize'
		private void tmr_resize_elapsed(System.Object o) {
			notify_resize.WakeupMain();
		}

		// effettua il resizing dell'immagine chiamando 'set_image_size'
		private void do_resize() {
			try {
				// ferma il timer e aggiorna le nuove dimensioni
				tmr_resize.Dispose();
				tmr_resize = null;
				Form1.GetSize(out w_foto, out h_foto);
			
				set_image_size();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// cambio del valore dei secondi
		private void spinSec_change(object o, EventArgs args) {
			if (n_foto > 0) statusBar.Push(0, Catalog.GetString("Loaded photos: ") + n_foto + " - " + Catalog.GetString("Slideshow time: ") + functions.show_time(ref spinSec, n_foto));
		}

		// apre lo wizard per la creazione di una galleria fotografica
		private void mnuNew_clicked(object o, EventArgs args) {
			// se c' una galleria aperta la chiude
			if (mnuChiudiG.Sensitive) mnuChiudiG.Activate();

			new wizardOne(store,scheda,spinSec,txtSuono,txtNome,mnuNew,statusBar,mnuSalva,mnuSalvaNome,mnuChiudiP,mnuCrea,Form1,barWork);
		}

		// termina il programma
		private void mnuEsci_clicked(object o, EventArgs args) {
			try {
				if (is_working) return;
				
				// chiude il progetto o la galleria
				if (mnuChiudiP.Sensitive) {
					mnuChiudiP.Activate();

					// controlla che non sia stato risposto cancel
					if (!close_window) return;
				}
				if (mnuChiudiG.Sensitive) mnuChiudiG.Activate();
			
				// salva le opzioni
				save_options();

				// salva i file recenti
				save_recent();
			
				Gtk.Application.Quit();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// apre la finestra delle preferenze
		private void mnuPreferenze_clicked(object o, EventArgs args) {
			new preferenze();
		}

		// crea la galleria fotografica
		private void mnuCrea_clicked(object o, EventArgs args) {
			try {
				if (mnuNew.Sensitive) return;
				if (n_foto == 0) {
					functions.message_box(Form1, MessageType.Warning, ButtonsType.Ok, false, Catalog.GetString("There isn't any photo"));

					return;
				}
				if (txtNome.Text.Trim() == "") {
					functions.message_box(Form1, MessageType.Warning, ButtonsType.Ok, false,  Catalog.GetString("You must give a name to the gallery"));

					return;
				}

				string[] f = functions.file_chooser(Form1, Catalog.GetString("Save gallery"), "ssg", "", FileChooserAction.Save, false);
				
				if (f.Length > 0 && f[0] != null && f[0] != "") {
					if (File.Exists(f[0])) {
						if (functions.message_box(Form1, MessageType.Question, ButtonsType.YesNo, false, Catalog.GetString("File already existing, do you want to overwrite it ?")) != ResponseType.Yes) return;
					}

					save_gallery(f[0]);

					// controlla se aprire automaticamente la galleria creata
					if (apri_galleria) {
						if (mnuChiudiP.Sensitive) {
							mnuChiudiP.Activate();

							// controlla che non sia stato risposto cancel
							if (!close_window) return;
						}
						if (mnuChiudiG.Sensitive) mnuChiudiG.Activate();

						load_gallery(f[0]);

						// inserisce il progetto nei recenti
						put_into_recent(f[0]);
					}
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// apre un progetto
		private void mnuApriP_clicked(object o, EventArgs args) {
			try {
				// chiude il progetto corrente
				if (mnuChiudiP.Sensitive) {
					mnuChiudiP.Activate();

					// controlla che non sia stato risposto cancel
					if (!close_window) return;
				}
				if (mnuChiudiG.Sensitive) mnuChiudiG.Activate();
		
				string[] file = functions.file_chooser(Form1, Catalog.GetString("Open project"), "ssp", Catalog.GetString("ssp project"), Gtk.FileChooserAction.Open, false);
				if (file.Length > 0 && file[0] != null && file[0] != "") {
					load_project(file[0]);

					// inserisce il progetto nei recenti
					put_into_recent(file[0]);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		private void mnuApriG_clicked(object o, EventArgs args) {
			try {
				// chiude il progetto corrente
				if (mnuChiudiP.Sensitive) {
					mnuChiudiP.Activate();

					// controlla che non sia stato risposto cancel
					if (!close_window) return;
				}
				if (mnuChiudiG.Sensitive) mnuChiudiG.Activate();

				string[] file = functions.file_chooser(Form1, Catalog.GetString("Open gallery"), "ssg", Catalog.GetString("ssg gallery"), Gtk.FileChooserAction.Open, false);
				if (file.Length > 0 && file[0] != null && file[0] != "") {
					load_gallery(file[0]);

					// inserisce il progetto nei recenti
					put_into_recent(file[0]);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// chiude la galleria
		private void mnuChiudiG_clicked(object o, EventArgs args) {
			try {
				nome_gallery = ""; path = ""; Form1.Title = "Super Slide Me"; spin_sec = 0; n_foto = 0; filtro = 0;
				statusBar.Push(0, Catalog.GetString("Loaded photos: ") + n_foto);

				// rimuove la cartella tmp nella in home/ssm se esiste
				if (Directory.Exists(home_dir + "/tmp")) Directory.Delete(home_dir + "/tmp", true);

				mnuChiudiG.Sensitive = false;
				mnuAvvia.Sensitive = false;
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// chiude il progetto corrente
		private void mnuChiudiP_clicked(object o, EventArgs args) {
			try {
				if (mnuNew.Sensitive) return;

				// se c' gi un altro progetto aperto chiede conferma
				if (!mnuNew.Sensitive) {
					ResponseType risposta = functions.message_box(Form1, MessageType.Question, ButtonsType.None, true, Catalog.GetString("Do you want to save the project ?"));

					if (risposta == ResponseType.Yes) mnuSalva.Activate();
					else if (risposta == ResponseType.Cancel) {
						close_window = false;
						return;
					}
				}

				close_window = true;
			
				store.Clear();
				n_foto = 0;
				statusBar.Push(0,Catalog.GetString("Loaded photos: ") + n_foto);
				imgFoto.Pixbuf = null;
				txtNome.Text = ""; spinSec.Value = 4; txtSuono.Text = ""; cboSize.Active = 2; cboCompression.Active = 3;
				nome_gallery = ""; path = ""; suono = ""; nome_progetto = ""; 

				mnuChiudiP.Sensitive = false;
				mnuSalva.Sensitive = false;
				mnuSalvaNome.Sensitive = false;
				mnuNew.Sensitive = true;
				mnuCrea.Sensitive = false;
				optBilinear.Active = true;
				scheda.Sensitive = false;
				chkForce.Active = false;
				chkProporzioni.Active = true;
				Form1.Title = "Super Slide Me";
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// Save project
		private void mnuSalva_clicked(object o, EventArgs args) {
			try {
				// controlla se  presente almeno una foto
				if (n_foto == 0) {
					functions.message_box(Form1, MessageType.Warning, ButtonsType.Ok, false, Catalog.GetString("To save your project you have to insert at least one image"));

					return;
				}
			
				// se non si tratta di un progetto gi esistente richiama la funzione salva con nome
				if (nome_progetto == "") mnuSalvaNome.Activate();
				else save_project(nome_progetto);
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		private void mnuSalvaNome_clicked(object o, EventArgs args) {
			try {
				// controlla se  presente almeno una foto
				if (n_foto == 0) {
					functions.message_box(Form1, MessageType.Warning, ButtonsType.Ok, false, Catalog.GetString("There isn't any photo"));

					return;
				}

				// apre la finestra di dialogo per la scelta del path e del nome del progetto
				string[] f = functions.file_chooser(Form1, Catalog.GetString("Save project as"), "ssp", "", Gtk.FileChooserAction.Save, false);
				if (f.Length > 0 && f[0] != null && f[0] != "") {
					// controlla se il file esiste gi
					if (File.Exists(f[0])) {
						if (functions.message_box(Form1, MessageType.Question, ButtonsType.YesNo, false, Catalog.GetString("File already existing, do you want to overwrite it ?")) != ResponseType.Yes) return;
					}

					// richiama la funzione per il salvataggio del progetto
					save_project(f[0]);
					nome_progetto = f[0];
					put_into_recent(f[0]);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		private void mnuPrimo_clicked(object o, EventArgs args) {
			open_recent(recent_list[0]);	
		}

		private void mnuSecondo_clicked(object o, EventArgs args) {
			open_recent(recent_list[1]);	
		}
		
		private void mnuTerzo_clicked(object o, EventArgs args) {
			open_recent(recent_list[2]);	
		}
		
		private void mnuQuarto_clicked(object o, EventArgs args) {
			open_recent(recent_list[3]);	
		}
		
		private void mnuQuinto_clicked(object o, EventArgs args) {
			open_recent(recent_list[4]);	
		}

		// elimina tutti i documenti recenti
		private void mnuPulisci_clicked(object o, EventArgs args) {
			try {
				for (int i = 0; i < 5; i++) recent_list[i] = "";

				((Gtk.Label)mnuPrimo.Child).Text = "";
				((Gtk.Label)mnuSecondo.Child).Text = "";
				((Gtk.Label)mnuTerzo.Child).Text = "";
				((Gtk.Label)mnuQuarto.Child).Text = "";
				((Gtk.Label)mnuQuinto.Child).Text = "";

				mnuPrimo.Visible = false;
				mnuSecondo.Visible = false;
				mnuTerzo.Visible = false;
				mnuQuarto.Visible = false;
				mnuQuinto.Visible = false;
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// avvia la presentazione
		private void mnuAvvia_clicked(object o, EventArgs args) {
			if (path != "") new presentazione(path);
		}

		// modifica del nome della galleria
		private void txtNome_changed(object o, EventArgs args) {
			Form1.Title = "Super Slide Me - " + txtNome.Text;
		}
		
		// aggiunge altre foto alla galleria
		private void cmdAdd_clicked(object o, EventArgs args) {
			try {
				string[] files = functions.file_chooser(Form1, Catalog.GetString("Add photo"), "jpg;JPG;jpeg;JPEG;gif;GIF;png;PNG", Catalog.GetString("images"), Gtk.FileChooserAction.Open, true);
				if (files.Length > 0 && files[0] != null && files[0] != "") {
					functions.load_dir(files,store,null,barWork);
					statusBar.Push(0,Catalog.GetString("Loaded photos: ") + n_foto + " - " + Catalog.GetString("Slideshow time: ") + functions.show_time(ref spinSec, n_foto));
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// aggiunge altre directory alla galleria
		private void cmdAddDir_clicked(object o, EventArgs args) {
			try {
				string[] d = functions.file_chooser(Form1, Catalog.GetString("Add folders"), "", "", Gtk.FileChooserAction.SelectFolder, true);
				if (d.Length > 0 && d[0] != null && d[0] != "") {
					int n = 0, c = 0;
				
					// calcola il numero di file per creare l'array
					for (int i = 0; i < d.Length; i++) n+= Directory.GetFiles(d[i]).Length;
				
					// prende tutti i file presenti nelle directory selezionate
					string[] f = new string[n];
				
					for (int i = 0; i < d.Length; i++) {
						string[] ft = Directory.GetFiles(d[i]);
						for (int j = 0; j < ft.Length; j++) {
							f[c] = ft[j];
							c++;
						}
					}

					functions.load_dir(f,store,null,barWork);
					statusBar.Push(0,Catalog.GetString("Loaded photos: ") + n_foto + " - " + Catalog.GetString("Slideshow time: ") + functions.show_time(ref spinSec, n_foto));
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// elimina la foto selezionata
		private void cmdElimina_clicked(object o, EventArgs args) {
			try {
				// controlla se c' una foto selezionata
				TreeModel model;
				TreeIter iter;

				if (!lista.Selection.GetSelected(out model, out iter)) return;
			
				if ((conf_elimina && functions.message_box(Form1, MessageType.Question, ButtonsType.YesNo, false, Catalog.GetString("Do you want to delete the selected photo ?")) == ResponseType.Yes) || (!conf_elimina)) {
					// elimina la foto selezionata
					store.Remove(ref iter);
					imgFoto.Pixbuf = null;
					n_foto--;
					if (n_foto > 0) statusBar.Push(0,Catalog.GetString("Loaded photos: ") + n_foto + " - " + Catalog.GetString("Slideshow time: ") + functions.show_time(ref spinSec, n_foto));
					else statusBar.Push(0,Catalog.GetString("Loaded photos: ") + n_foto);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// svuota tutta la galleria
		private void cmdPulisci_clicked(object o, EventArgs args) {
			try {
				// controlla se la galleria contiene qualche immagine
				TreeIter iter;

				if (!store.GetIterFirst(out iter)) return;
				
				if ((conf_pulisci && functions.message_box(Form1, MessageType.Question, ButtonsType.YesNo, false, Catalog.GetString("Do you want to delete all the photos in the gallery ?")) == ResponseType.Yes) || (!conf_pulisci)) {
					// pulisce tutta la galleria
					store.Clear();
					imgFoto.Pixbuf = null;
					n_foto = 0;
					statusBar.Push(0,Catalog.GetString("Loaded photos: ") + n_foto);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// apre la selezione file per il suono
		private void cmdSfoglia_clicked(object o, EventArgs args) {
			try {
				string[] f = functions.file_chooser(Form1, Catalog.GetString("Choose a sound"), "mp3;MP3;ogg;OGG;wav;WAV", Catalog.GetString("sound"), Gtk.FileChooserAction.Open, false);
				if (f.Length > 0 && f[0] != null && f[0] != "") txtSuono.Text = f[0];
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// crea la galleria fotografica se possibile
		private void cmdCrea_clicked(object o, EventArgs args) {
			mnuCrea.Activate();
		}

		// ruota di 90 in senso orario l'immagine
		private void cmdOrario_clicked(object o, EventArgs args) {
			try {
				TreeModel model;
				TreeIter iter;

				if (!lista.Selection.GetSelected(out model, out iter)) return;
			
				// imposta la rotazione
				string lato = store.GetValue(iter,2).ToString();
				if (lato == "") store.SetValue(iter,2,"r");
				else if (lato == "l") store.SetValue(iter,2,"");
				else if (lato == "r") store.SetValue(iter,2,"d");
				else if (lato == "d") store.SetValue(iter,2,"l");
				set_image_size();

				// sistema anche la preview caricando l'immagine gi ruotata a destra
				Gdk.Pixbuf minipix = imgFoto.Pixbuf;
				functions.size_preview(ref minipix);
				store.SetValue(iter, 0, minipix);
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// ruota di 90 in senso antiorario l'immagine
		private void cmdAntiorario_clicked(object o, EventArgs args) {
			try {
				TreeModel model;
				TreeIter iter;

				if (!lista.Selection.GetSelected(out model, out iter)) return;
			
				// imposta la rotazione
				string lato = store.GetValue(iter,2).ToString();
				if (lato == "") store.SetValue(iter,2,"l");
				else if (lato == "l") store.SetValue(iter,2,"d");
				else if (lato == "r") store.SetValue(iter,2,"");
				else if (lato == "d") store.SetValue(iter,2,"r");
				set_image_size();
				
				// sistema anche la preview caricando l'immagine gi ruotata a destra
				Gdk.Pixbuf minipix = imgFoto.Pixbuf;
				functions.size_preview(ref minipix);
				store.SetValue(iter, 0, minipix);
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// ruota di 180 l'immagine capovolgendola
		private void cmdCapovolgi_clicked(object o, EventArgs args) {
			try {
				TreeModel model;
				TreeIter iter;

				if (!lista.Selection.GetSelected(out model, out iter)) return;
			
				// imposta la rotazione
				string lato = store.GetValue(iter,2).ToString();
				if (lato == "") store.SetValue(iter,2,"d");
				else if (lato == "l") store.SetValue(iter,2,"r");
				else if (lato == "r") store.SetValue(iter,2,"l");
				else if (lato == "d") store.SetValue(iter,2,"");
				set_image_size();
				
				// sistema anche la preview caricando l'immagine gi ruotata a destra
				Gdk.Pixbuf minipix = imgFoto.Pixbuf;
				functions.size_preview(ref minipix);
				store.SetValue(iter, 0, minipix);
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}
		
		// visualizza la foto a destra
		private void lista_changed(object o, EventArgs args) {
			set_image_size();
		}

		// apre la foto nel visualizzatore
		private void lista_doubleclick(object o, RowActivatedArgs args) {
			TreeModel model;
			TreeIter iter;

			lista.Selection.GetSelected(out model, out iter);
			new visualizzatore(store.GetValue(iter,1).ToString(),store.GetValue(iter,2).ToString());
		}

		// sistema l'immagine per l'anteprima a destra
		private void set_image_size() {
			try {
				TreeModel model;
				TreeIter iter;
				int w,h;

				if (!lista.Selection.GetSelected(out model, out iter)) {
					imgFoto.FromPixbuf = null;
				
					return;
				}

				Gdk.Pixbuf pix = new Gdk.Pixbuf(store.GetValue(iter,1).ToString());
			
				Form1.GetSize(out w, out h);
			
				// controlla se l'immagine deve essere girata
				if (store.GetValue(iter,2).ToString() == "l") functions.rotate(store.GetValue(iter,1).ToString(), ref pix, 90);
				else if (store.GetValue(iter,2).ToString() == "r") functions.rotate(store.GetValue(iter,1).ToString(), ref pix, 270);
				else if (store.GetValue(iter,2).ToString() == "d") functions.rotate(store.GetValue(iter,1).ToString(), ref pix, 180);
			
				functions.size_preview_large(ref pix,w,h,false,true,Gdk.InterpType.Bilinear);

				imgFoto.FromPixbuf = pix;
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// carica le opzioni XML
		// ritorna true se tutto  ok, false in caso di errore
		private bool load_options() {
			try {
				if (!File.Exists(home_dir + "/options")) {
					// carica le preferenze nel nuovo formato XML se possibile
					if (!File.Exists(home_dir + "/preferences")) return false;
				
					XmlTextReader reader = new XmlTextReader(home_dir + "/preferences");

					while (reader.Read()) {
            		if (reader.NodeType == XmlNodeType.Element) {
							if (reader.Name == "option") {
								// controlla di quale opzione si tratta e ricava il valore
			            	string opt = reader["name"];
								reader.Read();
							
								switch (opt) {
								case "delete_photo":
									conf_elimina = XmlConvert.ToBoolean(reader.Value.ToLower());
									break;
								case "clear_gallery":
									conf_pulisci = XmlConvert.ToBoolean(reader.Value.ToLower());
									break;
								case "maximize":
									apri_big = XmlConvert.ToBoolean(reader.Value.ToLower());
									break;
								case "open_gallery":
									apri_galleria = XmlConvert.ToBoolean(reader.Value.ToLower());
									break;
								}
							}
						}
					}

					reader.Close();
				} else {
					// carica le opzioni nel formato vecchio per mantenere la compatibilit con le vecchie versioni					
					string linea;
					StreamReader r = File.OpenText(home_dir + "/options");

					if (r.Peek() > -1) linea = r.ReadLine().Trim();
					else return false;
					if (Convert.ToInt32(linea) != 0) conf_elimina = true;
					else conf_elimina = false;
			
					if (r.Peek() > -1) linea = r.ReadLine().Trim();
					else return false;
					if (Convert.ToInt32(linea) != 0) conf_pulisci = true;
					else conf_pulisci = false;

					if (r.Peek() > -1) linea = r.ReadLine().Trim();
					else return false;
					if (Convert.ToInt32(linea) != 0) apri_big = true;
					else apri_big = false;
			
					if (r.Peek() > -1) linea = r.ReadLine().Trim();
					else return false;
					if (Convert.ToInt32(linea) != 0) apri_galleria = true;
					else apri_galleria = false;

					r.Close();

					// adesso le salva nel nuovo formato ed elimina il file delle opzioni vecchio
					save_options();
					File.Delete(home_dir + "/options");
				}

				return true;
			} catch (Exception e) {
				Console.WriteLine(e);
				return false;
			}
		}

		// salva le opzioni su file di testo
		private void save_options() {
			try {
				// nuovo documento xml
            XmlDocument doc = new XmlDocument();

				// dichiarazione xml
				XmlDeclaration dec = doc.CreateXmlDeclaration("1.0", "", "yes");
				doc.PrependChild(dec);

				// elemento root e altre sottocategorie
				XmlElement root = doc.CreateElement("ssm");
				XmlElement generals = doc.CreateElement("generals");

				// aggiunge le opzioni
            save_xml(doc, generals, "delete_photo", conf_elimina.ToString());
            save_xml(doc, generals, "clear_gallery", conf_pulisci.ToString());
            save_xml(doc, generals, "maximize", apri_big.ToString());
            save_xml(doc, generals, "open_gallery", apri_galleria.ToString());

				root.AppendChild(generals);
				doc.AppendChild(root);
				
				// salva
				doc.Save(home_dir + "/preferences");
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// carica il progetto f
		private void load_project(string f) {
			try {
				ArrayList p = new ArrayList(); // lista di path
				ArrayList rot = new ArrayList(); // lista di rotazioni
				bool old_format = false;
				
				StreamReader r = File.OpenText(f);
				string first_line = "";

				if (!(first_line = r.ReadLine()).StartsWith("<?xml")) {
					// il file  in formato normale e lo legge per mantenere la compatibilit con le vecchie versioni
					old_format = true;
					
					// legge prima le opzioni
					txtNome.Text = first_line;
					Form1.Title = "Super Slide Me - " + txtNome.Text;
					txtSuono.Text = r.ReadLine();
					spinSec.Value = Convert.ToInt32(r.ReadLine());
				
					// dimensione delle immagini
					cboSize.Active = Convert.ToInt32(r.ReadLine());

					// tipo di immagine
					int q = Convert.ToInt32(r.ReadLine());
					if (q == 0) optJpg.Active = true;
					else optPng.Active = true;

					// tipo di compressione
					q = Convert.ToInt32(r.ReadLine());
					if (q == 0) optBilinear.Active = true;
					else optHyper.Active = true;

					// le due checkbox
					chkForce.Active = Convert.ToBoolean(r.ReadLine());
					chkProporzioni.Active = Convert.ToBoolean(r.ReadLine());
				
					// livello di compressione (controlla il valore per compatibilit con le versioni precedenti)
					q = Convert.ToInt32(r.ReadLine());
					if (q > 3) q = 3;
					cboCompression.Active = q;
				
					// numero di immagini (ormai obsoleto! mantenuto solo per compatibilit)
					r.ReadLine();

					// carica tutte le foto
					while (r.Peek() > -1) {
						string linea = r.ReadLine();
						p.Add(linea.Split(';')[0]);
						rot.Add(linea.Split(';')[1]);
					}

					r.Close();
				} else {
					// il file  nel nuovo formato XML
					r.Close();
					
					XmlTextReader reader = new XmlTextReader(f);

					while (reader.Read()) {
               	if (reader.NodeType == XmlNodeType.Element) {
							if (reader.Name == "option") {
								// controlla di quale opzione si tratta e ricava il valore
								string opt = reader["name"];

								reader.Read();

								if (opt == "gallery_name") {
									txtNome.Text = reader.Value.Trim();
									Form1.Title = "Super Slide Me - " + txtNome.Text;
								} else if (opt == "sound") txtSuono.Text = reader.Value.Trim();
								else if (opt == "seconds") spinSec.Value = Convert.ToInt32(reader.Value);
								else if (opt == "images_size") cboSize.Active = Convert.ToInt32(reader.Value);
								else if (opt == "compression") {
									int q = Convert.ToInt32(reader.Value);
									if (q > 3) q = 3;
									cboCompression.Active = q;
								} else if (opt == "images_format") optPng.Active = XmlConvert.ToBoolean(reader.Value);
								else if (opt == "interpolation") optHyper.Active = XmlConvert.ToBoolean(reader.Value);
								else if (opt == "force_resize") chkForce.Active = XmlConvert.ToBoolean(reader.Value.ToLower());
								else if (opt == "keep_ratio") chkProporzioni.Active = XmlConvert.ToBoolean(reader.Value.ToLower());
								else if (opt.StartsWith("photo ")) {
									p.Add(reader.Value.Split(';')[0]);
									rot.Add(reader.Value.Split(';')[1]);
								}
							}
						}
					}

					reader.Close();
				}
				
				scheda.Sensitive = true;
				nome_progetto = f;
				mnuNew.Sensitive = false;
				mnuCrea.Sensitive = true;
				mnuSalva.Sensitive = true;
				mnuSalvaNome.Sensitive = true;
				mnuChiudiP.Sensitive = true;

				// mette il contenuto delle liste in due vettori per mantenere la compatibilit con la 'load_dir'
				string[] pv = new string[p.Count];
				string[] rotv = new string[rot.Count];
				for (int i = 0; i < pv.Length; i++) {
					pv[i] = p[i].ToString();
					rotv[i] = rot[i].ToString();
				}
			
				// richiama la funzione per caricare tutte le immagini
				functions.load_dir(pv,store,rotv,barWork);
				statusBar.Push(0,Catalog.GetString("Loaded photos: ") + n_foto + " - " + Catalog.GetString("Slideshow time: ") + functions.show_time(ref spinSec, n_foto));

				// avvisa l'utente che il file  nel formato vecchio se necessario
				if (old_format) functions.message_box(Form1, MessageType.Warning, ButtonsType.Ok, false, Catalog.GetString("The format of this file is old. Please save this project to update the file to the new format"));
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// carica la galleria per la visualizzazione
		private void load_gallery(string f) {
			try {
				if (is_working) return;
				
				FileStream fs;
				ZipInputStream s = new ZipInputStream(File.OpenRead(f));
				ZipEntry entry;

				// calcola il numero di step per la progress bar
				uint steps = 0;
				for (int i = 0; i < 3; i++) entry = s.GetNextEntry();
				while ((entry = s.GetNextEntry()) != null) steps++;
				s.Close();

				// controlla che non ci sia la cartella temporanea, altrimenti la elimina
				if (Directory.Exists(home_dir + "/tmp")) Directory.Delete(home_dir + "/tmp", true);
				if (!Directory.Exists(home_dir)) Directory.CreateDirectory(home_dir);
				if (!Directory.Exists(home_dir + "/tmp")) Directory.CreateDirectory(home_dir + "/tmp");
				
				s = new ZipInputStream(File.OpenRead(f));

				int size = 2048;
				byte[] data = new byte[size];
			
				entry = s.GetNextEntry();
				s.Read(data,0,size);
				string options = new UTF8Encoding().GetString(data, 0, size).Trim();

				if (options.StartsWith("<?xml")) {
					// legge le opzioni nel nuovo formato XML
					// salva il contenuto di options in un file temporaneo per parsare l'XML
					StreamWriter w = File.CreateText(home_dir + "/tmp/options");
					w.Write(options);
					w.Close();

					XmlTextReader reader = new XmlTextReader(home_dir + "/tmp/options");

					while (reader.Read()) {
						if (reader.NodeType == XmlNodeType.Element) {
							if (reader.Name == "option") {
								// controlla di quale opzione si tratta e ricava il valore
								string opt = reader["name"];
							
								reader.Read();

								switch (opt) {
								case "gallery_name":
									nome_gallery = reader.Value.Trim();
									break;
								case "seconds":
									spin_sec = Convert.ToInt32(reader.Value);
									break;
								case "keep_ratio":
									propor = XmlConvert.ToBoolean(reader.Value.ToLower());
									break;
								case "interpolation":
									filtro = Convert.ToInt32(reader.Value);
									break;
								}
							}
						}
					}

					reader.Close();

					// elimina il file temporaneo
					File.Delete(home_dir + "/tmp/options");
				} else {
					// legge le opzioni nel vecchio formato per mantenere la compatibilit con le vecchie versioni				
					nome_gallery = options.Split('\n')[0].Trim();
					spin_sec = Convert.ToInt32(options.Split('\n')[1]);
					propor = Convert.ToBoolean(options.Split('\n')[2]);
					filtro = Convert.ToInt32(options.Split('\n')[3]);
				}

				Form1.Title = "Super Slide Me - " + nome_gallery;
			
				// salta le due cartelle pixmaps e sound
				for (int i = 0; i < 2; i++) entry = s.GetNextEntry();

				n_foto = 0;
				int current_step = 0;
		
				is_working = true;
				create_progress(barWork, steps);
				
				while ((entry = s.GetNextEntry()) != null) {
					set_progress(barWork, ++current_step);
					
					fs = new FileStream(home_dir + "/tmp/" + entry.Name.Split('/')[1],System.IO.FileMode.Create,System.IO.FileAccess.Write);
					size = 2048;
					while (size > 0) {
						size = s.Read(data,0,data.Length);
						fs.Write(data,0,size);
					}

					fs.Close();

					if (!entry.Name.Split('/')[1].EndsWith("mp3") && !entry.Name.Split('/')[1].EndsWith("wav") && !entry.Name.Split('/')[1].EndsWith("ogg")) n_foto++;
				
					// tiene libera la GUI
					while (Gtk.Application.EventsPending()) Gtk.Application.RunIteration();
				}

				s.Close();

				destroy_progress(barWork);
				is_working = false;

				// richiama il visualizzatore di gallerie
				path = home_dir + "/tmp";

				mnuAvvia.Sensitive = true;
				mnuChiudiG.Sensitive = true;
				Gtk.SpinButton spin = new Gtk.SpinButton(0,30,1);
				spin.Value = spin_sec;
				statusBar.Push(0, Catalog.GetString("Loaded photos: ") + n_foto + " - " + Catalog.GetString("Slideshow time: ") + functions.show_time(ref spin, n_foto));

				mnuAvvia.Activate();
			} catch (Exception e) {
				Console.WriteLine(e);
				destroy_progress(barWork);
				is_working = false;
			}
		}

		// salva il progetto su file f in formato XML
		private void save_project(string f) {
			try {
				if (is_working) return;
			
				// nuovo documento xml
				XmlDocument doc = new XmlDocument();
				
				// dichiarazione xml
				XmlDeclaration dec = doc.CreateXmlDeclaration("1.0", "", "yes");
				doc.PrependChild(dec);
				
				// elemento root e altre sottocategorie
				XmlElement root = doc.CreateElement("ssm_project");
				XmlElement options = doc.CreateElement("options");
				XmlElement photos = doc.CreateElement("photos");

				// aggiunge le opzioni
            save_xml(doc, options, "gallery_name", txtNome.Text);
            save_xml(doc, options, "sound", txtSuono.Text);
            save_xml(doc, options, "seconds", spinSec.Value.ToString());
            save_xml(doc, options, "images_size", cboSize.Active.ToString());
            save_xml(doc, options, "compression", cboCompression.Active.ToString());
            save_xml(doc, options, "images_format", (Convert.ToInt32(optPng.Active)).ToString());
            save_xml(doc, options, "interpolation", (Convert.ToInt32(optHyper.Active)).ToString());
            save_xml(doc, options, "force_resize", chkForce.Active.ToString());
            save_xml(doc, options, "keep_ratio", chkProporzioni.Active.ToString());
				
				is_working = true;
				create_progress(barWork, (uint)n_foto);

				// memorizza il path e la rotazione delle immagini
				int current_step = 0;
				TreeIter iter;
				store.GetIterFirst(out iter);
				do {
					set_progress(barWork, ++current_step);
					save_xml(doc, photos, "photo " + current_step.ToString(), store.GetValue(iter,1).ToString() + ";" + store.GetValue(iter,2).ToString());
				} while (store.IterNext(ref iter));

				root.AppendChild(options);
				root.AppendChild(photos);
				doc.AppendChild(root);
				
				// salva
				doc.Save(f);

				destroy_progress(barWork);
				is_working = false;
			} catch (Exception e) {
				Console.WriteLine(e);
				destroy_progress(barWork);
				is_working = false;
			}
		}

		// salva la galleria su file f
		private void save_gallery(string f) {
			try {
				if (is_working) return;
				
				if (Directory.Exists(home_dir + "/tmp")) Directory.Delete(home_dir + "/tmp",true);
				if (!Directory.Exists(home_dir)) Directory.CreateDirectory(home_dir);
				Directory.CreateDirectory(home_dir + "/tmp");
			
				// scrive un file in formato XML contenente alcune informazioni
				XmlDocument doc = new XmlDocument();

				// dichiarazione xml
				XmlDeclaration dec = doc.CreateXmlDeclaration("1.0", "", "yes");
				doc.PrependChild(dec);

				// elemento root e altre sottocategorie
				XmlElement root = doc.CreateElement("ssm_gallery");
				XmlElement options = doc.CreateElement("options");

				// aggiunge le opzioni
				save_xml(doc, options, "gallery_name", txtNome.Text);
				save_xml(doc, options, "seconds", spinSec.Value.ToString());
				save_xml(doc, options, "keep_ratio", chkProporzioni.Active.ToString());
				save_xml(doc, options, "interpolation", (Convert.ToInt32(optHyper.Active)).ToString());

				root.AppendChild(options);
				doc.AppendChild(root);

				doc.Save(home_dir + "/tmp/data");
				
				// crea un archivio zip
				ZipOutputStream outStream = new ZipOutputStream(File.Create(f));

				// setta il livello di compressione
				switch (cboCompression.Active) {
				case 0: 
					outStream.SetLevel(9);
					break;
				case 1:
					outStream.SetLevel(5);
					break;
				case 2:
					outStream.SetLevel(2);
					break;
				default:
					outStream.SetLevel(0);
					break;
				}
			
				// inserisce il file data
				add_to_zip(ref outStream,home_dir + "/tmp/" + "data","data");

				// crea le directory pixmaps e sound
				add_to_zip(ref outStream,"","pixmaps/");
				add_to_zip(ref outStream,"","sound/");
			
				// inserisce il suono se esiste
				if (txtSuono.Text != "" && File.Exists(txtSuono.Text)) {
					string ext = txtSuono.Text.Substring(txtSuono.Text.Length-3);
					if (ext == "mp3" || ext == "ogg" || ext == "wav") add_to_zip(ref outStream,txtSuono.Text,"sound/sound." + ext);
				}

				is_working = true;
				create_progress(barWork, (uint)n_foto);
				
				// copia tutte le foto della galleria nella cartella pixmaps	
				int i = 0, current_step = 0;
				TreeIter iter;
				store.GetIterFirst(out iter);
				do {
					set_progress(barWork, ++current_step);
					
					Gdk.Pixbuf pix = new Gdk.Pixbuf(store.GetValue(iter,1).ToString());

					// controlla se eseguire una rotation
					if (store.GetValue(iter,2).ToString() == "l") functions.rotate(store.GetValue(iter,1).ToString(), ref pix, 90);
					else if (store.GetValue(iter,2).ToString() == "r") functions.rotate(store.GetValue(iter,1).ToString(), ref pix, 270);
					else if (store.GetValue(iter,2).ToString() == "d") functions.rotate(store.GetValue(iter,1).ToString(), ref pix, 180);

					// ridimensiona in base alla qualit scelta nelle opzioni
					int h = 0, wd = 0;
					if (cboSize.Active == 0) { wd = 890; h = 630; } // 640x480
					else if (cboSize.Active == 1) { wd = 1050; h = 750; } // 800x600
					else if (cboSize.Active == 2) { wd = 1274; h = 918; } // 1024x768

					// se sono state scelte le dimensioni originali non effettua il ridimensionamento
					if (cboSize.Active != 3) {
						if (optBilinear.Active) functions.size_preview_large(ref pix,wd,h,chkForce.Active,chkProporzioni.Active,Gdk.InterpType.Bilinear);
						else functions.size_preview_large(ref pix,wd,h,chkForce.Active,chkProporzioni.Active,Gdk.InterpType.Hyper);
					}
					
					// salva l'immagine su file
					string num = i.ToString();
					if (num.Length == 1) num = "00" + num;
					else if (num.Length == 2) num = "0" + num;
					if (optJpg.Active) pix.Save(home_dir + "/tmp/" + "img" + num + ".jpg","jpeg");
					else pix.Save(home_dir + "/tmp/" + "img" + num + ".png","png");
					i++;
					
					if (optJpg.Active) {
						add_to_zip(ref outStream,home_dir + "/tmp/" + "img" + num + ".jpg","pixmaps/img" + num + ".jpg");
					} else {
						add_to_zip(ref outStream,home_dir + "/tmp/" + "img" + num + ".png","pixmaps/img" + num + ".png");
					}
				
					// tiene libera la GUI
					while (Gtk.Application.EventsPending()) Gtk.Application.RunIteration();
				} while (store.IterNext(ref iter));

				outStream.Close();
				destroy_progress(barWork);
				is_working = false;
			} catch (Exception e) {
				Console.WriteLine(e);
				destroy_progress(barWork);
				is_working = false;
			}
		}

		// aggiunge un file o una cartella all'archivio outStream	
		private void add_to_zip(ref ZipOutputStream outStream, string f, string n) {
			try {
				FileStream fs;
				byte[] buffer = new byte[0];
				if (f != "") {
					fs = File.OpenRead(f);
					buffer = new byte[fs.Length];
					fs.Read(buffer,0,buffer.Length);
					fs.Close();
				}
				ZipEntry entry = new ZipEntry(n);
				outStream.PutNextEntry(entry);
				if (f != "") outStream.Write(buffer,0,buffer.Length);
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// legge da file di testo gli ultimi documenti recenti e li carica nel menu e in un vettore
		private void load_recent() {
			try {
				if (!File.Exists(home_dir + "/recent")) return;
				StreamReader r = File.OpenText(home_dir + "/recent");

				for (int i = 0; i < 5 && r.Peek() > -1; i++) {
					string linea = r.ReadLine().Trim();
				
					if (linea == "") return;

					recent_list[i] = linea;
					string file = "";
					if (unix_sys) file = linea.Substring(linea.LastIndexOf("/")+1);
					else file = linea.Substring(linea.LastIndexOf("\\")+1);

					switch (i) {
					case 0: 
						((Gtk.Label)mnuPrimo.Child).Text = file;
						mnuPrimo.Visible = true;
						break;
					case 1:
						((Gtk.Label)mnuSecondo.Child).Text = file;
						mnuSecondo.Visible = true;
						break;
					case 2:
						((Gtk.Label)mnuTerzo.Child).Text = file;
						mnuTerzo.Visible = true;
						break;
					case 3:
						((Gtk.Label)mnuQuarto.Child).Text = file;
						mnuQuarto.Visible = true;
						break;
					case 4:
						((Gtk.Label)mnuQuinto.Child).Text = file;
						mnuQuinto.Visible = true;
						break;
					}	
				}

				r.Close();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// salva la lista dei recenti dal vettore al file recent
		private void save_recent() {
			try {
				StreamWriter w = File.CreateText(home_dir + "/recent");
			
				for (int i = 0; i < 5; i++) {
					if (recent_list[i] != "") w.WriteLine(recent_list[i]);
				}

				w.Close();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// inserisce in testa ai recenti il file f
		private void put_into_recent(string f) {
			try {
				// se il file  gi presente nei recenti non lo aggiunge
				bool presente = false;

				string c;
				if (!unix_sys) c = "\\";
				else c = "/";
				
				for (int i = 0; i < 5 && !presente; i++) {
					if (f == recent_list[i]) presente = true;
				}

				if (presente) return;
				
				for (int i = 3; i > -1; i--) {
					if (recent_list[i] != "") {
						recent_list[i+1] = recent_list[i];

						switch (i) {
						case 0:
							((Gtk.Label)mnuSecondo.Child).Text = ((Gtk.Label)mnuPrimo.Child).Text;
							mnuSecondo.Visible = true;
							break;
						case 1:
							((Gtk.Label)mnuTerzo.Child).Text = ((Gtk.Label)mnuSecondo.Child).Text;
							mnuTerzo.Visible = true;
							break;
						case 2:
							((Gtk.Label)mnuQuarto.Child).Text = ((Gtk.Label)mnuTerzo.Child).Text;
							mnuQuarto.Visible = true;
							break;
						case 3:
							((Gtk.Label)mnuQuinto.Child).Text = ((Gtk.Label)mnuQuarto.Child).Text;
							mnuQuinto.Visible = true;
							break;
						}
					}
				}
			
				((Gtk.Label)mnuPrimo.Child).Text = f.Substring(f.LastIndexOf(c)+1);
				mnuPrimo.Visible = true;
				recent_list[0] = f;
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// apre il file recente f se possibile
		private void open_recent(string f) {
			try {
				// controlla se il file esiste
				if (!File.Exists(f)) {
					functions.message_box(Form1, MessageType.Error, ButtonsType.Ok, false, Catalog.GetString("File doesn't exists"));

					return;
				}

				// controlla che estensione ha per sapere se  un progetto o una galleria
				if (f.Substring(f.Length - 3) == "ssp") {
					if (mnuChiudiP.Sensitive) {
						mnuChiudiP.Activate();

						// controlla che non sia stato risposto cancel
						if (!close_window) return;
					}
					if (mnuChiudiG.Sensitive) mnuChiudiG.Activate();
				
					load_project(f);

					// inserisce il progetto nei recenti
					put_into_recent(f);
				} else if (f.Substring(f.Length - 3) == "ssg") {
					if (mnuChiudiP.Sensitive) {
						mnuChiudiP.Activate();

						// controlla che non sia stato risposto cancel
						if (!close_window) return;
					}
					if (mnuChiudiG.Sensitive) mnuChiudiG.Activate();
				
					load_gallery(f);

					// inserisce il progetto nei recenti
					put_into_recent(f);
				} else functions.message_box(Form1, MessageType.Error, ButtonsType.Ok, false, Catalog.GetString("File format is wrong"));
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}
	}

	public class wizardOne {

		[Widget] Gtk.Window Form2;
		[Widget] Gtk.Button cmdSfoglia;
		[Widget] Gtk.Button cmdNext;
		[Widget] Gtk.Entry txtNome;
		[Widget] Gtk.Entry txtPath;
		[Widget] Gtk.Image imgWizard, imgAvanti;
		[Widget] Gtk.Label lblNome, lblPath, lblStep, lblSfoglia, lblNext;

		Gtk.Window Form1;
		Gtk.Notebook scheda;
		Gtk.SpinButton spinSec;
		Gtk.Entry txtSuono, nome;
		Gtk.ListStore store;
		Gtk.MenuItem mnuNew;
		Gtk.ImageMenuItem mnuSalva, mnuSalvaNome, mnuChiudiP, mnuCrea;
		Gtk.Statusbar statusBar;
		Gtk.ProgressBar barWork;

		public wizardOne(Gtk.ListStore store, Gtk.Notebook scheda, Gtk.SpinButton spinSec, Gtk.Entry txtSuono, Gtk.Entry nome, Gtk.MenuItem mnuNew, Gtk.Statusbar statusBar, Gtk.ImageMenuItem mnuSalva, Gtk.ImageMenuItem mnuSalvaNome, Gtk.ImageMenuItem mnuChiudiP, Gtk.ImageMenuItem mnuCrea, Gtk.Window Form1, Gtk.ProgressBar barWork) {
			try {
				this.Form1 = Form1;
				this.store = store;
				this.scheda = scheda;
				this.spinSec = spinSec;
				this.txtSuono = txtSuono;
				this.nome = nome;
				this.mnuNew = mnuNew;
				this.mnuCrea = mnuCrea;
				this.mnuSalva = mnuSalva;
				this.mnuSalvaNome = mnuSalvaNome;
				this.mnuChiudiP = mnuChiudiP;
				this.statusBar = statusBar;
				this.barWork = barWork;
			
				Glade.XML glade = new Glade.XML(null, "ssm.glade","Form2","SuperSlideMe");
				glade.Autoconnect(this);

				imgWizard.FromFile = ssm.c_dir + "pixmaps/step1.png";
			
				functions.set_window_icon(Form2, ssm.c_dir + "pixmaps/icon.png");
				imgAvanti.FromFile = ssm.c_dir + "pixmaps/right.png";

				Form2.Title = ssm.Catalog.GetString("Wizard");
				lblNome.Text = ssm.Catalog.GetString("Photogallery name");
				lblPath.Text = ssm.Catalog.GetString("Images path");
				lblStep.Text = ssm.Catalog.GetString("Step 1 of 3");
				lblNext.Text = ssm.Catalog.GetString("Next");
				lblSfoglia.Text = ssm.Catalog.GetString("Browse...");
			
				// segnali
				cmdSfoglia.Clicked += cmdSfoglia_clicked;
				cmdNext.Clicked += cmdNext_clicked;
			
				Form2.ShowAll();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		private void cmdSfoglia_clicked(object o, EventArgs args) {
			// apre la finestra di selezione files
			string[] d = functions.file_chooser(Form2, ssm.Catalog.GetString("Add folder"), "", "", Gtk.FileChooserAction.SelectFolder, false);
			if (d.Length > 0 && d[0] != null && d[0] != "") txtPath.Text = d[0];
		}

		private void cmdNext_clicked(object o, EventArgs args) {
			// controlla che ci sia il nome della galleria
			if (txtNome.Text == "") {
				functions.message_box(Form2, MessageType.Warning, ButtonsType.Ok, false, ssm.Catalog.GetString("You must give the name to the gallery"));

				return;
			}

			ssm.nome_gallery = txtNome.Text;

			// memorizza il path se  corretto in una variabile e passa allo step numero 2
			if (txtPath.Text != "" && Directory.Exists(txtPath.Text)) ssm.path = txtPath.Text;
			
			// chiude la form2
			Form2.Destroy();
				
			new wizardTwo(store,scheda,spinSec,txtSuono,nome,mnuNew,statusBar,mnuSalva,mnuSalvaNome,mnuChiudiP,mnuCrea,Form1,barWork);
		}
	}

	public class wizardTwo {

		[Widget] Gtk.Window Form3;
		[Widget] Gtk.Button cmdSfoglia;
		[Widget] Gtk.Button cmdNext;
		[Widget] Gtk.Entry txtSuono;
		[Widget] Gtk.SpinButton spinSec;
		[Widget] Gtk.Image imgWizard, imgAvanti;
		[Widget] Gtk.Label lblSecondi, lblSuono, lblStep, lblNext, lblSfoglia;

		Gtk.Window Form1;
		Gtk.ListStore store;
		Gtk.Notebook scheda;
		Gtk.SpinButton spin;
		Gtk.Entry suono, nome;
		Gtk.MenuItem mnuNew;
		Gtk.ImageMenuItem mnuSalva, mnuSalvaNome, mnuChiudiP, mnuCrea;
		Gtk.Statusbar statusBar;
		Gtk.ProgressBar barWork;
		
		public wizardTwo(Gtk.ListStore store, Gtk.Notebook scheda, Gtk.SpinButton spin, Gtk.Entry suono, Gtk.Entry nome, Gtk.MenuItem mnuNew, Gtk.Statusbar statusBar, Gtk.ImageMenuItem mnuSalva, Gtk.ImageMenuItem mnuSalvaNome, Gtk.ImageMenuItem mnuChiudiP, Gtk.ImageMenuItem mnuCrea, Gtk.Window Form1, Gtk.ProgressBar barWork) {
			try {
				this.Form1 = Form1;
				this.store = store;
				this.scheda = scheda;
				this.spin = spin;
				this.suono = suono;
				this.nome = nome;
				this.mnuNew = mnuNew;
				this.mnuCrea = mnuCrea;
				this.mnuSalva = mnuSalva;
				this.mnuSalvaNome = mnuSalvaNome;
				this.mnuChiudiP = mnuChiudiP;
				this.statusBar = statusBar;
				this.barWork = barWork;
			
				Glade.XML glade = new Glade.XML(null, "ssm.glade","Form3","SuperSlideMe");
				glade.Autoconnect(this);
			
				imgWizard.FromFile = ssm.c_dir + "pixmaps/step2.png";

				functions.set_window_icon(Form3, ssm.c_dir + "pixmaps/icon.png");
				imgAvanti.FromFile = ssm.c_dir + "pixmaps/right.png";

				Form3.Title = ssm.Catalog.GetString("Wizard");
				lblSecondi.Text = ssm.Catalog.GetString("Seconds");
				lblSuono.Text = ssm.Catalog.GetString("Sound");
				lblNext.Text = ssm.Catalog.GetString("Next");
				lblSfoglia.Text = ssm.Catalog.GetString("Browse...");
				lblStep.Text = ssm.Catalog.GetString("Step 2 of 3");
			
				// segnali
				cmdNext.Clicked += cmdNext_clicked;
				cmdSfoglia.Clicked += cmdSfoglia_clicked;

				Form3.ShowAll();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		private void cmdSfoglia_clicked(object o, EventArgs args) {
			// apre la finestra di selezione files
			string[] f = functions.file_chooser(Form3, ssm.Catalog.GetString("Choose a sound"), "mp3;MP3;ogg;OGG;wav;WAV", ssm.Catalog.GetString("sound"), Gtk.FileChooserAction.Open, false);
			if (f.Length > 0 && f[0] != null && f[0] != "") txtSuono.Text = f[0];
		}

		private void cmdNext_clicked(object o, EventArgs args) {
			// controlla il valore dello spin button
			if (spinSec.ValueAsInt < 1 || spinSec.ValueAsInt > 30) {
				functions.message_box(Form3, MessageType.Warning, ButtonsType.Ok, false, ssm.Catalog.GetString("Seconds value is wrong"));

				return;
			}

			ssm.spin_sec = spinSec.ValueAsInt;

			// se  stato scelto un suono controlla la sua validit e lo memorizza in una variabile
			if (txtSuono.Text != "" && check_sound(txtSuono.Text)) ssm.suono = txtSuono.Text;

			// chiude la form3 e passa all'ultimo step
			Form3.Destroy();

			new wizardThree(store,scheda,spin,suono,nome,mnuNew,statusBar,mnuSalva,mnuSalvaNome,mnuChiudiP,mnuCrea,Form1,barWork);
		}

		// controlla se la stringa s  un suono valido (wav,mp3,ogg)
		private bool check_sound(string s) {
			if (File.Exists(s)) {
				string ext = s.Substring(s.Length-3);
				if (ext == "wav" || ext == "mp3" || ext == "ogg") return true;
			}

			return false;
		}
	}

	public class wizardThree {

		[Widget] Gtk.Window Form4;
		[Widget] Gtk.Button cmdFine;
		[Widget] Gtk.Image imgWizard, imgFine;
		[Widget] Gtk.Label lblFine, lblStep, lblEnd;

		Gtk.Window Form1;
		Gtk.ListStore store;
		Gtk.Notebook scheda;
		Gtk.SpinButton spinSec;
		Gtk.Entry txtSuono, txtNome;
		Gtk.MenuItem mnuNew;
		Gtk.ImageMenuItem mnuSalva,mnuSalvaNome,mnuChiudiP,mnuCrea;
		Gtk.Statusbar statusBar;
		Gtk.ProgressBar barWork;

		public wizardThree(Gtk.ListStore store, Gtk.Notebook scheda, Gtk.SpinButton spinSec, Gtk.Entry txtSuono, Gtk.Entry txtNome, Gtk.MenuItem mnuNew, Gtk.Statusbar statusBar, Gtk.ImageMenuItem mnuSalva, Gtk.ImageMenuItem mnuSalvaNome, Gtk.ImageMenuItem mnuChiudiP, Gtk.ImageMenuItem mnuCrea, Gtk.Window Form1, Gtk.ProgressBar barWork) {
			try {
				this.Form1 = Form1;
				this.store = store;
				this.scheda = scheda;
				this.spinSec = spinSec;
				this.txtSuono = txtSuono;
				this.txtNome = txtNome;
				this.mnuNew = mnuNew;
				this.mnuCrea = mnuCrea;
				this.mnuSalva = mnuSalva;
				this.mnuSalvaNome = mnuSalvaNome;
				this.mnuChiudiP = mnuChiudiP;
				this.statusBar = statusBar;
				this.barWork = barWork;
			
				Glade.XML glade = new Glade.XML(null, "ssm.glade","Form4","SuperSlideMe");
				glade.Autoconnect(this);

				imgWizard.FromFile = ssm.c_dir + "pixmaps/step3.png";
				
				functions.set_window_icon(Form4, ssm.c_dir + "pixmaps/icon.png");
				imgFine.FromFile = ssm.c_dir + "pixmaps/end.png";

				Form4.Title = ssm.Catalog.GetString("Wizard");
				lblFine.Text = ssm.Catalog.GetString("Wizard is finished. Click on \"End\" button to create the photogallery!");
				lblStep.Text = ssm.Catalog.GetString("Step 3 of 3");
				lblEnd.Text = ssm.Catalog.GetString("End");
			
				// segnali
				cmdFine.Clicked += cmdFine_clicked;

				Form4.ShowAll();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		private void cmdFine_clicked(object o, EventArgs args) {
			try {
				// termina la procedura guidata sistemando gli oggetti della finestra principale
				scheda.Sensitive = true;
				spinSec.Value = ssm.spin_sec;
				txtSuono.Text = ssm.suono;
				txtNome.Text = ssm.nome_gallery;
				Form1.Title = "Super Slide Me - " + ssm.nome_gallery;
				mnuNew.Sensitive = false;
				mnuCrea.Sensitive = true;
				mnuSalva.Sensitive = true;
				mnuSalvaNome.Sensitive = true;
				mnuChiudiP.Sensitive = true;

				// carica le immagini importate se ci sono
				if (Directory.Exists(ssm.path)) {
					// apre la finestra di attesa
					Form4.Hide();
					functions.load_dir(Directory.GetFiles(ssm.path),store,null,barWork);
				}

				if (ssm.n_foto > 0) statusBar.Push(0, ssm.Catalog.GetString("Loaded photos: ") + ssm.n_foto + " - " + ssm.Catalog.GetString("Slideshow time: ") + functions.show_time(ref spinSec, ssm.n_foto));
				else statusBar.Push(0, ssm.Catalog.GetString("Loaded photos: ") + ssm.n_foto);
				Form4.Destroy();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}
	}

	public class visualizzatore {

		[Widget] Gtk.Window Form5;
		[Widget] Gtk.Image imgFoto;

		// ridimensiona l'immagine (800x600~)
		private void adjust_size(ref Gdk.Pixbuf pix) {
			try {
				int h;
				int w = 0;
			
				// prima ridimensiona fissando la larghezza se necessario
				if (pix.Width > 800 || pix.Height > 600) {
					// ricalcola l'altezza
					h = (pix.Height * 800) / pix.Width;

					// se l'altezza non entra nel range 600 ridimensiona in base all'altezza
					if (h > 600) w = (pix.Width * 600) / pix.Height;

					// scala l'immagine
					if (w == 0) pix = pix.ScaleSimple(800,h,Gdk.InterpType.Bilinear);
					else pix = pix.ScaleSimple(w,600,Gdk.InterpType.Bilinear);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		public visualizzatore(string f, string r) {
			Glade.XML glade = new Glade.XML(null, "ssm.glade","Form5","SuperSlideMe");
			glade.Autoconnect(this);
				
			Form5.Title = ssm.Catalog.GetString("Image viewer");
			Form5.ModifyBg(Gtk.StateType.Normal, new Gdk.Color(0,0,0));
			functions.set_window_icon(Form5, ssm.c_dir + "pixmaps/icon.png");

			Form5.ShowAll();
			Form5.Maximize();

			Gdk.Pixbuf pix = new Gdk.Pixbuf(f);

			// controlla se bisogna girare l'immagine
			if (r == "l") functions.rotate(f, ref pix, 90);
			else if (r == "r") functions.rotate(f, ref pix, 270);
			else if (r == "d") functions.rotate(f, ref pix, 180);
			
			adjust_size(ref pix);

			imgFoto.FromPixbuf = pix;
		}
	}

	public class preferenze {
		
		[Widget] Gtk.Window Form6;
		[Widget] Gtk.CheckButton chkElimina, chkPulisci, chkBig, chkGalleria;
		[Widget] Gtk.Button cmdSalva;
		[Widget] Gtk.Label lblGenerali;

		public preferenze() {
			Glade.XML glade = new Glade.XML(null, "ssm.glade","Form6","SuperSlideMe");
			glade.Autoconnect(this);

			cmdSalva.Clicked += cmdSalva_clicked;

			functions.set_window_icon(Form6, ssm.c_dir + "pixmaps/preferences.png");

			Form6.Title = ssm.Catalog.GetString("Preferences");
			lblGenerali.Markup = ssm.Catalog.GetString("<b>Generals</b>");
			chkElimina.Label = ssm.Catalog.GetString("Ask confirm when deleting a photo");
			chkPulisci.Label = ssm.Catalog.GetString("Ask confirm when clearing the gallery");
			chkBig.Label = ssm.Catalog.GetString("Maximize main window at start");
			chkGalleria.Label = ssm.Catalog.GetString("Open gallery after its creation");

			load_options();
			
			Form6.ShowAll();
		}

		// salva le opzioni nelle variabili statiche
		private void cmdSalva_clicked(object o, EventArgs args) {
			ssm.conf_elimina = chkElimina.Active;
			ssm.conf_pulisci = chkPulisci.Active;
			ssm.apri_big = chkBig.Active;
			ssm.apri_galleria = chkGalleria.Active;

			// chiude la finestra
			Form6.Destroy();
		}

		// carica le opzioni dalle variabili
		private void load_options() {
			chkElimina.Active = ssm.conf_elimina;
			chkPulisci.Active = ssm.conf_pulisci;
			chkBig.Active = ssm.apri_big;
			chkGalleria.Active = ssm.apri_galleria;
		}
	}

	// la presentazione della galleria
	public class presentazione {

		[Widget] Gtk.Window Form8;
		[Widget] Gtk.Image imgFoto, imgPlayPause, imgPrev, imgNext, imgQuit;
		[Widget] Gtk.Label lblCont, lblLoop;
		[Widget] Gtk.HBox menu;
		[Widget] Gtk.Button cmdPlayPause, cmdPrev, cmdNext, cmdEsci;
		[Widget] Gtk.CheckButton chkLoop;

		Gtk.Window finestra;

		// timer che gestiscono la presentazione
		System.Threading.Timer tmr, tmr_titolo, tmr_mouse;
		
		// callback dei timer che gestiscono le funzioni che devono richiamare i timer
		TimerCallback tmr_del, tmr_titolo_del, tmr_mouse_del;
      
		// thread che vengono richiamati dalle funzioni di callback dei timer per gestire eventi grafici safe
		ThreadNotify notify, notify_titolo, notify_mouse;
		
		Music mus;
			
		int secondi_timer = ssm.spin_sec * 1000; // numero di secondi tra un'immagine e l'altra
		bool mouse_visible = true;
		int corr = 0, screen_width = 0, screen_height = 0;
		string[] immagine; // vettore di immagini
		string suono = "";
		
		public presentazione(string path) {
			try {
				Glade.XML glade = new Glade.XML(null, "ssm.glade","Form8","SuperSlideMe");
				glade.Autoconnect(this);

				Form8.KeyPressEvent += Form8_keypress;
				Form8.MotionNotifyEvent += Form8_mousemove;
				cmdPlayPause.Clicked += cmdPlayPause_clicked;
				cmdPrev.Clicked += cmdPrev_clicked;
				cmdNext.Clicked += cmdNext_clicked;
				cmdEsci.Clicked += cmdEsci_clicked;
				chkLoop.Toggled += chkLoop_clicked;
				
				// ricava la risoluzione dello schermo
				Gdk.Screen screen = Gdk.Screen.Default;
				screen_width = screen.Width;
				screen_height = screen.Height;
				
				// collega ai thread le funzioni
				notify = new ThreadNotify(new ReadyEvent(view_image));
				notify_titolo = new ThreadNotify(new ReadyEvent(view_title));
				notify_mouse = new ThreadNotify(new ReadyEvent(hide_mouse));

				// crea i callback dei timer che poi richiameranno le funzioni sopra
				tmr_del = new TimerCallback(tmr_elapsed);
				tmr_titolo_del = new TimerCallback(tmr_titolo_elapsed);
				tmr_mouse_del = new TimerCallback(tmr_mouse_elapsed);
				
				// carica tutte le immagini in un vettore
				immagine = Directory.GetFiles(path);

				// se c' il suono lo toglie dal vettore e lo memorizza in una variabile
				if (immagine[immagine.Length-1].EndsWith("mp3") || immagine[immagine.Length-1].EndsWith("ogg") || immagine[immagine.Length-1].EndsWith("wav")) {
					suono = immagine[immagine.Length-1];
					immagine[immagine.Length-1] = "";
				}

				Form8.Fullscreen();
				Form8.ShowAll();
				
				// crea una finestra per visualizzare il nome della galleria
				finestra = new Gtk.Window("");
				finestra.TransientFor = Form8;
				finestra.DestroyWithParent = true;

				Gtk.Label lblTitolo = new Gtk.Label(ssm.nome_gallery);
				Pango.FontDescription fd = new Pango.FontDescription();
				fd.Weight = Pango.Weight.Heavy;
				fd.Size = screen_width * 45;
				lblTitolo.ModifyFont(fd);
				lblTitolo.ModifyFg(Gtk.StateType.Normal, new Gdk.Color(255,255,255));
				finestra.Add(lblTitolo);
				finestra.Fullscreen();
				Form8.ModifyBg(Gtk.StateType.Normal, new Gdk.Color(0,0,0));
				finestra.ModifyBg(Gtk.StateType.Normal, new Gdk.Color(0,0,0));
				lblCont.ModifyFg(Gtk.StateType.Normal, new Gdk.Color(255,255,255));
				chkLoop.ModifyBg(Gtk.StateType.Prelight, new Gdk.Color(0,0,0));
				lblLoop.ModifyFg(Gtk.StateType.Normal, new Gdk.Color(255,255,255));
				lblLoop.Text = ssm.Catalog.GetString("Loop");

				finestra.ShowAll();
				tmr_titolo = new System.Threading.Timer(tmr_titolo_del, null, 5000, 5000);

				// setta il cursore invisibile e sistema il menu
				finestra.GdkWindow.Cursor = functions.ghost_cursor();
				Form8.GdkWindow.Cursor = functions.ghost_cursor();
				mouse_visible = false;
				menu.Visible = false;

				imgPlayPause.FromFile = ssm.c_dir + "pixmaps/play.png";
				imgPrev.FromFile = ssm.c_dir + "pixmaps/left.png";
				imgNext.FromFile = ssm.c_dir + "pixmaps/right.png";
				imgQuit.FromFile = ssm.c_dir + "pixmaps/exit.png";

				mus = Mixer.Music;
				if (suono != "") mus.Load(suono);
			} catch (Exception e) {
				Console.WriteLine(e);
				suono = "";
			}
		}

		// quando si muove il mouse
		private void Form8_mousemove(object o, MotionNotifyEventArgs args) {			
			show_menu();
		}

		// pressione del tasto esc
		private void Form8_keypress(object o, KeyPressEventArgs args) {
			try {
				if (args.Event.KeyValue == 65307) {
					if (suono != "") { mus.Stop(); mus.Dispose(); }
					if (tmr != null) tmr.Dispose();
					if (tmr_titolo != null) tmr_titolo.Dispose();
					if (tmr_mouse != null) tmr_mouse.Dispose();
					Form8.Destroy();
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// tasto play/pausa
		private void cmdPlayPause_clicked(object o, EventArgs args) {
			try {
				// si trasforma in tasto play o in tasto pausa e ferma o riavvia il timer della presentazione
				if (tmr != null) {
					tmr.Dispose(); tmr = null;
					imgPlayPause.FromFile = ssm.c_dir + "pixmaps/play.png";
				} else {
					tmr = new System.Threading.Timer(tmr_del, null, 1000, secondi_timer);
					imgPlayPause.FromFile = ssm.c_dir + "pixmaps/pause.png";
				}

				// stoppa e riavvia il timer del mouse
				if (tmr_mouse != null) {
					tmr_mouse.Dispose();
					tmr_mouse = new System.Threading.Timer(tmr_mouse_del, null, 5000, 5000);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// visualizza la foto precedente
		private void cmdPrev_clicked(object o, EventArgs args) {
			try {
				// ferma la presentazione
				if (tmr != null) cmdPlayPause.Click();

				if (corr < 2) return;
			
				corr -= 2;
				view_image(); // richiama la funzione per visualizzare l'immagine
			
				// stoppa e riavvia il timer del mouse
				if (tmr_mouse != null) {
					tmr_mouse.Dispose();
					tmr_mouse = new System.Threading.Timer(tmr_mouse_del, null, 5000, 5000);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// visualizza la foto successiva
		private void cmdNext_clicked(object o, EventArgs args) {
			try {
				// stoppa la presentazione
				if (tmr != null) cmdPlayPause.Click();

				if (corr == immagine.Length || immagine[corr] == "") {
					if (!chkLoop.Active) return;
					else {
						// ricomincia dall'inizio
						corr = 0;
					}
				}

				// visualizza l'immagine
				view_image();
			
				// stoppa e riavvia il timer del mouse
				if (tmr_mouse != null) {
					tmr_mouse.Dispose();
					tmr_mouse = new System.Threading.Timer(tmr_mouse_del, null, 5000, 5000);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// chiude la finestra di presentazione
		private void cmdEsci_clicked(object o, EventArgs args) {
			try {
				if (suono != "") { mus.Stop(); mus.Dispose(); }
				if (tmr != null) { tmr.Dispose(); tmr = null; }
				if (tmr_titolo != null) { tmr_titolo.Dispose(); tmr_titolo = null; }
				if (tmr_mouse != null) { tmr_mouse.Dispose(); tmr_mouse = null; }
				Form8.Destroy();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// click sulla check del loop
		private void chkLoop_clicked(object o, EventArgs args) {
			try {
				if (chkLoop.Active) cmdNext.Sensitive = true;
				else {
					// disabilita solo se si  sull'ultima immagine
					if (corr == immagine.Length) cmdNext.Sensitive = false;
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// evento del timer della presentazione
		private void tmr_elapsed(System.Object o) {
			notify.WakeupMain();
		}

		// evento del timer del titolo
		private void tmr_titolo_elapsed(System.Object o) {
			notify_titolo.WakeupMain();
		}

		// evento del timer del mouse
		private void tmr_mouse_elapsed(System.Object o) {
			notify_mouse.WakeupMain();
		}

		// visualizza la prossima immagine presente nella galleria
		private void view_image() {
			try {
				// fa ripartire la musica se necessario
				if (suono != "" && !mus.IsPlaying()) mus.Play(-1);

				// controlla se ci sono ancora immagini
				if (corr == immagine.Length || immagine[corr] == "") {
					if (!chkLoop.Active) {
						if (suono != "") { mus.Stop(); mus.Dispose(); }
						if (tmr != null) { tmr.Dispose(); tmr = null; }
						if (tmr_mouse != null) { tmr_mouse.Dispose(); tmr_mouse = null; }
						Form8.Destroy();

						return;
					} else corr = 0;
				}
			
				Gdk.Pixbuf pix = new Gdk.Pixbuf(immagine[corr]);

				// se l'immagine  pi grande della risoluzione dello schermo la rimpicciolisce controllando il flag proporzioni
				// se l'immagine  pi piccola della risoluzione dello schermo la ingrandisce forzandola
				if (pix.Width != screen_width || pix.Height != screen_height) {
					if (ssm.filtro == 0) functions.size_preview_large(ref pix,screen_width + 250,screen_height + 150,true,ssm.propor,Gdk.InterpType.Bilinear);
					else functions.size_preview_large(ref pix,screen_width + 250,screen_height + 150,true,ssm.propor,Gdk.InterpType.Hyper);
				}
				imgFoto.FromPixbuf = pix;
				
				corr++;

				lblCont.Text = corr + ssm.Catalog.GetString(" of ") + ssm.n_foto;

				if ((corr == immagine.Length || immagine[corr] == "") && !chkLoop.Active) cmdNext.Sensitive = false;
				else cmdNext.Sensitive = true;

				if (corr == 1) cmdPrev.Sensitive = false;
				else cmdPrev.Sensitive = true;
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// visualizza la finestra con il titolo della presentazione
		private void view_title() {
			try {
				// ferma il timer del titolo
				if (tmr_titolo != null) { tmr_titolo.Dispose(); tmr_titolo = null; }

				// fa partire il timer della presentazione
				tmr = new System.Threading.Timer(tmr_del, null, 0, secondi_timer);

				// distrugge la finestra del titolo
				finestra.Destroy();
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// nasconde il mouse e il menu
		private void hide_mouse() {
			try {
				// ferma il timer del mouse
				if (tmr_mouse != null) {tmr_mouse.Dispose(); tmr_mouse = null; }
				
				Form8.GdkWindow.Cursor = functions.ghost_cursor();
				mouse_visible = false;
				menu.Visible = false;
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}

		// visualizza il cursore del mouse e il menu
		private void show_menu() {
			try {
				// lo fa solo se il tutto non  visibile
				if (!mouse_visible) {
					Form8.GdkWindow.Cursor = null;
					mouse_visible = true;
					menu.Visible = true;
					
					// fa partire il timer del mouse
					tmr_mouse = new System.Threading.Timer(tmr_mouse_del, null, 5000, 5000);
				}
			} catch (Exception e) {
				Console.WriteLine(e);
			}
		}
	}

	public class informazioni {
		
		[Widget] Gtk.Window Form9;
		[Widget] Gtk.TextView txtInfo;

		public informazioni() {
			Glade.XML glade = new Glade.XML(null, "ssm.glade","Form9","SuperSlideMe");
			glade.Autoconnect(this);
			
			functions.set_window_icon(Form9, ssm.c_dir + "pixmaps/information.png");
			Form9.Title = ssm.Catalog.GetString("Super Slide Me informations");
			txtInfo.Buffer.Text = ssm.Catalog.GetString("Version: 1.0\nAuthor: Alessio Carminati\nLicense: GNU (GPL)\nLanguage: C#\nURL: http://www.nongnu.org/ssm/\n\nTranslators:\nItalian: Alessio Carminati\nEnglish: Alessio Carminati\n\nSpecial thanks to:\nAndrea Bertolazzi (idea)\nMarco Marche (zip lib help)\nIlaria Firmian (wizard photo)\nGiacomo Franceschini (wizard photo)");
			
			Form9.ShowAll();
		}
	} // end class informazioni
}
